@@ -1,32 +1,7 @@
-/*
- * (c) 2017, Deepin Technology Co., Ltd. <support@deepin.org>
- *
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License as
- * published by the Free Software Foundation; either version 3 of the
- * License, or (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful, but
- * is provided AS IS, WITHOUT ANY WARRANTY; without even the implied
- * warranty of MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE, and
- * NON-INFRINGEMENT.  See the GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, see <http://www.gnu.org/licenses/>.
- *
- * In addition, as a special exception, the copyright holders give
- * permission to link the code of portions of this program with the
- * OpenSSL library under certain conditions as described in each
- * individual source file, and distribute linked combinations
- * including the two.
- * You must obey the GNU General Public License in all respects
- * for all of the code used other than OpenSSL.  If you modify
- * file(s) with this exception, you may extend this exception to your
- * version of the file(s), but you are not obligated to do so.  If you
- * do not wish to do so, delete this exception statement from your
- * version.  If you delete this exception statement from all source
- * files in the program, then also delete it here.
- */
+// SPDX-FileCopyrightText: 2022 UnionTech Software Technology Co., Ltd.
+//
+// SPDX-License-Identifier: GPL-3.0-or-later
+
 #ifndef _DMR_MAIN_WINDOW_H
 #define _DMR_MAIN_WINDOW_H
 
@@ -48,6 +23,7 @@
 #include "actions.h"
 #include "online_sub.h"
 #include "compositing_manager.h"
+#include "mircastshowwidget.h"
 
 class Presenter;
 
@@ -133,12 +109,7 @@ public:
         QWidget(parent)
     {
         setWindowFlags(Qt::FramelessWindowHint);
-        if (!CompositingManager::get().composited()) {
-            setWindowFlags(Qt::Tool | Qt::FramelessWindowHint);
-        }
-#if defined (__aarch64__) || defined (__mips__)
-        setWindowFlags(Qt::Tool | Qt::FramelessWindowHint);
-#endif
+
         m_pTimer = new QTimer(this);
 
         setFixedHeight(40);
@@ -252,6 +223,10 @@ signals:
      * @brief 字幕菜单是否可用信号
      */
     void subtitleMenuEnable(bool);
+    /**
+     * @brief soundMenuEnable 声音字幕是否可用信号
+     */
+    void soundMenuEnable(bool);
     /**
      * @brief 窗口特效变化信号
      */
@@ -359,6 +334,7 @@ public slots:
      * @param 影片路径
      */
     void play(const QList<QString> &listFiles);
+    void slotFinishedAddFiles(QList<QUrl>);
     void updateProxyGeometry();
     void suspendToolsWindow();
     void resumeToolsWindow();
@@ -414,6 +390,16 @@ public slots:
      */
     void slotVolumeChanged(int nVolume);
     void slotWMChanged(QString msg);
+    void slotMediaError();
+    /**
+     * @brief slotUpdateMircastState 更新投屏状态槽函数
+     * @param state 投屏状态
+     */
+    void slotUpdateMircastState(int state, QString msg);
+    /**
+     * @brief slotExitMircast 退出投屏槽函数
+     */
+    void slotExitMircast();
 
 protected:
     void showEvent(QShowEvent *pEvent) override;
@@ -505,6 +491,11 @@ private:
     void setPlaySpeedMenuChecked(ActionFactory::ActionKind);
     void setPlaySpeedMenuUnchecked();
     void setMusicShortKeyState(bool bState);
+    /**
+     * @brief mircastSuccess 投屏成功更新界面
+     */
+    void mircastSuccess(QString name);
+    void exitMircast();
 
 private:
     MessageWindow *m_pPopupWid;                     ///截图提示窗口
@@ -580,12 +571,14 @@ private:
     QDBusInterface *m_pDBus;
     Presenter *m_pPresenter;
     MovieWidget *m_pMovieWidget;
+    MircastShowWidget *m_pMircastShowWidget;          ///投屏展示界面
     qint64 m_nFullscreenTime;                         ///全屏操作间隔时间
     QDBusInterface *m_pWMDBus {nullptr};              ///窗口特效dbus接口
     bool m_bIsWM {true};                              ///是否开启窗口特效
     bool m_isSettingMiniMode{false};                  ///mini mode setting status
     Qt::WindowStates m_preMiniWindowState {Qt::WindowNoState};  ///window state before mini mode
-    bool m_bMaximized;                                ///全屏前最大化窗口记录        
+    bool m_bMaximized;                                ///全屏前最大化窗口记录
+    bool m_bHaveFile;                                 ///导入是否包含文件（用于导入文件或文件夹）
 };
 };
 
