@@ -100,17 +100,17 @@ CompositingManager::CompositingManager()
     bool isDriverLoaded = isDriverLoadedCorrectly();
     softDecodeCheck();   //检测是否是kunpeng920（是否走软解码）
 
-    bool isI915 = false;
-    for (int id = 0; id <= 10; id++) {
-        if (!QFile::exists(QString("/sys/class/drm/card%1").arg(id))) break;
-        if (is_device_viable(id)) {
-            vector<string> drivers = {"i915"};
-            isI915 = is_card_exists(id, drivers);
-            break;
-        }
-    }
-    if (isI915) qInfo() << "is i915!";
-    m_bZXIntgraphics = isI915 ? isI915 : m_bZXIntgraphics;
+//    bool isI915 = false;
+//    for (int id = 0; id <= 10; id++) {
+//        if (!QFile::exists(QString("/sys/class/drm/card%1").arg(id))) break;
+//        if (is_device_viable(id)) {
+//            vector<string> drivers = {"i915"};
+//            isI915 = is_card_exists(id, drivers);
+//            break;
+//        }
+//    }
+//    if (isI915) qInfo() << "is i915!";
+//    m_bZXIntgraphics = isI915 ? isI915 : m_bZXIntgraphics;
 
     if (dmr::utils::check_wayland_env()) {
         _composited = true;
@@ -129,7 +129,8 @@ CompositingManager::CompositingManager()
         return;
     }
 
-    _composited = false;
+    _composited = true;
+#if defined (_MOVIE_USE_)
     QGSettings gsettings("com.deepin.deepin-movie", "/com/deepin/deepin-movie/");
     QString aa = gsettings.get("composited").toString();
     if ((gsettings.get("composited").toString() == "DisableComposited"
@@ -154,6 +155,8 @@ CompositingManager::CompositingManager()
             _composited = false;
         }
     }
+#endif
+
     //针对9200显卡适配
     QFileInfo jmfi("/dev/jmgpu");
     if (jmfi.exists()) {
